@@ -1,7 +1,7 @@
 import string
 from random import choice
 
-from bip32keys.bip32addresses import Bip32Addresses
+from utils.bip32keys.bip32addresses import Bip32Addresses
 
 
 class Qtum(Bip32Addresses):
@@ -53,9 +53,11 @@ def test_signature():
     signature = Qtum.sign_message(message, private_key)
     print(Qtum.verify_message(message, signature, public_key))
 
+
 def generate_token(length=16, chars=string.ascii_letters + string.punctuation + string.digits):
     return "".join(choice(chars) for x in range(0, length))
 
+
 if __name__ == '__main__':
     # test_address()
     # test_signature()
