@@ -1,23 +1,19 @@
-import os
-import sys
+from .keys import SIGN_PUB_KEY, SIGN_PRV_KEY
+from utils.qtum_utils.qtum import Qtum
+
 
 def verify(func):
     async def wrapper(*args, **kwargs):
-        import settings
-        with open(os.path.join(settings.BASE_DIR, "keys.json")) as f:
-            keys = json.load(f)
-
-        pubkey = keys["pubkey"]
 
         message = kwargs.get("message")
         signature = kwargs.get("signature")
         try:
-            flag = Qtum.verify_message(message, signature, pubkey)
+            flag = Qtum.verify_message(message, signature, SIGN_PUB_KEY)
         except:
             flag = None
         if not flag:
-            result =  {"error":403, "reason":"Invalid signature"}
+            result = {"error": 403, "reason": "Invalid signature"}
         else:
             result = await func(*args, **kwargs)
         return result
-    return wrapper
\ No newline at end of file
+    return wrapper
